import setuptools
setuptools.setup(
    name = "exdatetime",
    version = "0.1.0",
    author = "ericoder",
    author_email = "ericshen0@yeah.net",
    description = "Designed to extend from the module datetime of Python",
    url = "https://github.com/shenyouran/exdatetime",
)    
